# Welcome to AgentScope Studio

AgentScope Studio is a web-based platform for monitoring, managing and developing multi-agent applications in AgentScope! Feel free to explore the platform and its features.

## Start to explore AgentScope Studio with

Dashboard
Monitor and manage your AgentScope running instances.
Workstation
Develop your multi-agent applications by dragging.
Gallery
Coming soon ...
Server Management
Coming soon ...